SystemOrganization addCategory: #'Seaside-Tools-Core'!

WAObject subclass: #WAAdmin
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tools-Core'!

!WAAdmin class methodsFor: 'private' stamp: 'jf 3/4/2009 10:58'!
applicationDefaults
	^ WASharedConfiguration named: 'Application Defaults' ifNew: [ :config |
		config
			addParent: WARenderLoopConfiguration instance;
			at: #responseGenerator put: WAHtmlResponseGenerator ]! !

!WAAdmin class methodsFor: 'private' stamp: 'jf 3/4/2009 10:58'!
applicationExceptionHandlingDefaults
	^ WASharedConfiguration named: 'Application Exception Handling Defaults' ifNew: [ :config |
		config
			addParent: WAExceptionFilterConfiguration instance;
			at: #exceptionHandler put: WAHtmlErrorHandler ]! !

!WAAdmin class methodsFor: 'development' stamp: 'jf 9/17/2008 20:58'!
clearConfigurationCaches
	WASystemConfiguration clearAllDescriptions! !

!WAAdmin class methodsFor: 'development' stamp: 'jf 10/27/2008 11:27'!
clearSessions
	WARegistry clearAll! !

!WAAdmin class methodsFor: 'registration' stamp: 'jf 3/4/2009 10:59'!
configureNewApplication: anApplication
	| filter |
	anApplication configuration
		removeParent: WAApplicationConfiguration instance; "make the chain slightly cleaner"
		addParent: WARenderLoopConfiguration instance;
		addParent: self applicationDefaults.
		
	filter := WAExceptionFilter new.
	filter configuration addParent: self applicationExceptionHandlingDefaults.
	anApplication addFilter: filter! !

!WAAdmin class methodsFor: 'private' stamp: 'jf 10/26/2008 12:19'!
defaultDispatcher
	^ WADispatcher default! !

!WAAdmin class methodsFor: 'initialization' stamp: 'lr 10/21/2008 15:35'!
initialize
	self reloadApplications! !

!WAAdmin class methodsFor: 'registration' stamp: 'jf 1/30/2009 17:35'!
register: aComponentClass asApplicationAt: aString
	"Use this to programatically register a component as an application."
	"WARenderLoopConfiguration is added by default because most users will use WASession and the Render Loop."
	| application |
	application := self register: WAApplication at: aString.
	self configureNewApplication: application.
	application preferenceAt: #rootClass put: aComponentClass.
	^ application! !

!WAAdmin class methodsFor: 'registration' stamp: 'jf 1/22/2009 02:43'!
register: aComponentClass asApplicationAt: aString user: user password: password
	"Like #register:asApplicationAt: but additionally adds password protection."
	| application |
	application := self register: aComponentClass asApplicationAt: aString.
	application configuration addParent: WAAuthConfiguration instance.
	application 
		preferenceAt: #login
		put: user.
	application 
		preferenceAt: #passwordHash
		put: (WAPlatform current secureHashFor: password).
	application
		addFilter: WAAuthenticationFilter new.
	^ application! !

!WAAdmin class methodsFor: 'registration' stamp: 'jf 10/26/2008 12:19'!
register: anEntryPointClass at: aString
	^ self register: anEntryPointClass at: aString in: self defaultDispatcher! !

!WAAdmin class methodsFor: 'registration' stamp: 'jf 10/26/2008 12:15'!
register: anEntryPointClass at: aString in: aDispatcher
	| path dispatcher |
	path := aString findTokens: '/'.
	dispatcher := path allButLast
		inject: aDispatcher
		into: [ :result :each |
			result entryPoints 
				at: each
				ifAbsent: [ result register: (WADispatcher named: each) ] ].
	^ dispatcher register: (anEntryPointClass named: path last)! !

!WAAdmin class methodsFor: 'registration' stamp: 'jf 2/3/2009 17:28'!
registerDefaultComponents
	WAPainter allSubclasses do: [ :each |
		(each class includesSelector: #initialize)
			ifTrue: [ each initialize ] ]! !

!WAAdmin class methodsFor: 'registration' stamp: 'jf 11/9/2008 18:00'!
registerDefaultRequestHandlers
	WAFileHandler default: (WAFileHandler named: 'files').
	WAFileHandler default preferenceAt: #fileHandlerListingClass put: WAHtmlFileHandlerListing.
	WADispatcher default register: WAFileHandler default! !

!WAAdmin class methodsFor: 'development' stamp: 'lr 10/21/2008 15:30'!
reloadApplications
	WADispatcher resetDefault.
	WASystemConfiguration clearAllDescriptions.
	self registerDefaultRequestHandlers.
	self registerDefaultComponents! !

!WAPackage class methodsFor: '*seaside-tools-core' stamp: 'jf 3/14/2009 11:48'!
seasideToolsCore
	^ self new
		name: 'Seaside-Tools-Core';
		description: 'Administrative tools, useful to have for production and development environments.';
		addDependency: 'Seaside-Core';
		addDependency: 'Seaside-Component';
		addDependency: 'Seaside-RenderLoop';
		addDependency: 'Seaside-Session';
		addDependency: 'Seaside-Canvas';
		yourself! !

!WAComponent class methodsFor: '*seaside-tools-core' stamp: 'lr 12/30/2008 12:48'!
registerAsApplication: aString 
	self
		seasideDeprecatedApi: 'WAComponent class>>#registerAsApplication:'
		details: 'Use WAAdmin class>>#register:asApplicationAt:.'.
	^ WAAdmin register: self asApplicationAt: aString! !

!WAEntryPoint class methodsFor: '*seaside-tools-core' stamp: 'lr 12/30/2008 12:48'!
register: aString
	self
		seasideDeprecatedApi: 'WAEntryPoint class>>#register:'
		details: 'Use WAAdmin class>>#register:at:.'.
	^ WAAdmin register: self at: aString! !

!WAEntryPoint class methodsFor: '*seaside-tools-core' stamp: 'lr 12/30/2008 12:48'!
register: aString in: aDispatcher
	self
		seasideDeprecatedApi: 'WAEntryPoint class>>#register:in:'
		details: 'Use WAAdmin class>>#register:at:in:.'.
	^ WAAdmin register: self at: aString in: aDispatcher! !

!WADispatcher class methodsFor: '*seaside-tools-core' stamp: 'lr 12/30/2008 12:48'!
resetAll
	self
		seasideDeprecatedApi: 'WADispatcher class>>#resetAll'
		details: 'Use WAAdmin>>#reloadApplications.'.
	WAAdmin reloadApplications! !
WAAdmin initialize!
